@@ -2,12 +2,13 @@ package Alien::Build::Plugin::Fetch::Local;
 
 use strict;
 use warnings;
+use 5.008004;
 use Alien::Build::Plugin;
 use File::chdir;
 use Path::Tiny ();
 
 # ABSTRACT: Plugin for fetching a local file
-our $VERSION = '1.98'; # VERSION
+our $VERSION = '2.40'; # VERSION
 
 
 has '+url' => '';
@@ -46,7 +47,9 @@ sub init
   }
 
   $meta->register_hook( fetch => sub {
-    my(undef, $path) = @_;
+    my($build, $path, %options) = @_;
+
+    $build->log("plugin Fetch::Local does not support http_headers option") if $options{http_headers};
 
     $path ||= $self->url;
 
@@ -102,7 +105,7 @@ Alien::Build::Plugin::Fetch::Local - Plugin for fetching a local file
 
 =head1 VERSION
 
-version 1.98
+version 2.40
 
 =head1 SYNOPSIS
 
@@ -213,6 +216,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
